# This is a useful tool created by Wayne

## Currently includes:
- data-structure
- dsp
- gui
- math
- tools
- tt_api
- ocs_api

# Installation
Try to run "pip install pywayne" in your commond line tool.

# How to use
from pywayne.tools import *

files = list_all_files(path_to_root)

...

# P.S.
Feel free to contact me whenever you need help using this tool.

e-mail: wang121ye@hotmail.com

leetcode: http://leetcode.com/wangyehope

github: http://github.com/wangyendt

Pull-requests are always welcomed.

Hopefully this may help you somewhere!
